@@ -847,7 +847,8 @@ public abstract class CompilerProject implements ICompilerProject
         return fatalProblems == null ? Collections.<ICompilerProblem>emptyList() : fatalProblems;
     }
 
-    @Override
+    @SuppressWarnings("incomplete-switch")
+	@Override
     public ITypeDefinition getBuiltinType(IASLanguageConstants.BuiltinType type)
     {
         switch( type )
@@ -1014,4 +1015,8 @@ public abstract class CompilerProject implements ICompilerProject
         return (baseDefinition == overrideDefinition);
 	}
 
+	public boolean isParameterCountMismatchAllowed(IFunctionDefinition func,
+			int formalCount, int actualCount) {
+        return false;
+	}
 }
